package extmedias

import (
	"github.com/jmoiron/sqlx"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/sqly"
)

const (
	addExternalMediaQuery    = `INSERT INTO external_medias (type, source, category, ids) VALUES ($1, $2, $3, $4) RETURNING id;`
	updateExternalMediaQuery = `UPDATE external_medias SET type=:type, source=:source, category=:category, ids=:ids WHERE id=:id RETURNING *;`

	deleteExternalMediaQuery = `DELETE FROM external_medias WHERE id=:id;`
	getExternalMediaQuery    = `SELECT * FROM external_medias WHERE type=$1 AND source=$2 AND category=$3 LIMIT 1;`
)

// Media represents an external media
type Media struct {
	sqly.BaseModel
	Type     string           `db:"type"`
	Source   string           `db:"source"`
	Category string           `db:"category"`
	IDs      sqly.StringSlice `db:"ids"`
}

// Add adds the Media in the database
func (m *Media) Add(q sqlx.Queryer) error {
	var id string
	err := q.QueryRowx(addExternalMediaQuery, m.Type, m.Source, m.Category, m.IDs).Scan(&id)
	if err != nil {
		return err
	}
	m.ID = id
	return nil
}

// Update ids only updates the IDs of the media
func (m *Media) Update(ex *sqlx.DB) error {
	rows, err := ex.NamedQuery(updateExternalMediaQuery, m)
	if err != nil {
		return err
	}
	for rows.Next() {
		rows.StructScan(m)
	}
	return nil
}

// Delete the media from database or raise an error
func (m *Media) Delete(ex *sqlx.DB) error {
	_, err := ex.NamedExec(deleteExternalMediaQuery, m)
	return err
}

// Get gets a media
func Get(q sqlx.Queryer, mtype, msrc, mcat string) (*Media, error) {
	m := &Media{}
	if err := q.QueryRowx(getExternalMediaQuery, mtype, msrc, mcat).StructScan(m); err != nil {
		return nil, err
	}

	return m, nil
}
