import React from 'react'
import axios from 'axios'

function MoviePosters(props) {
  // TODO handle the limit from the url
  const perPage = 30;

  let movies;
  // Let's limit the number for now
  if (props.movies.length > perPage) {
    movies = props.movies.slice(0, perPage);
  } else {
    movies = props.movies;
  }

  return (
    <div className="col-xs-5 col-md-8">
      <div className="row">
        {movies.map(function(movie, index) {
          const selected = (index === props.selectedMovieIndex) ? true : false;
          return (
            <MoviePoster
              data={movie}
              key={movie.ID}
              selected={selected}
              onClick={() => props.onClick(index)}
            />
          )}
        )}
      </div>
    </div>
  );
}

class MoviePoster extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      src: `/img/movies/${this.props.data.imdb_id}.jpg`,
    }
    this.handleError = this.handleError.bind(this);
  }
  handleError() {
    this.setState({ src: '/img/noimage.png' });
  }
  render() {
    const selected = this.props.selected ? ' thumbnail-selected' : '';
    const imgClass = 'thumbnail' + selected;
    return (
      <div className="col-xs-12 col-md-3">
        <a className={imgClass}>
          <img
            src={this.state.src}
            onClick={this.props.onClick}
            onError={this.handleError}
          />
        </a>
      </div>
    );
  }
}

function MovieDetails(props) {
  return (
    <div className="col-xs-7 col-md-4">
      <div className="movie-detail affix">
        <h1 className="hidden-xs">{props.data.title}</h1>
        <h3 className="visible-xs">{props.data.title}</h3>
        <p>
          <i className="fa fa-clock-o"></i>
          {props.data.runtime} min
        </p>
        <p>
          <i className="fa fa-star-o"></i>
          {props.data.rating} <small>({props.data.votes} counts)</small>
        </p>
        <p className="movie-plot">{props.data.plot}</p>
      </div>
    </div>
  );
}

export default class MovieList extends React.Component {
  componentWillMount() {
    this.props.fetchMovies(this.props.moviesUrl);
  }
  render() {
    const movies = this.props.movieStore.movies;
    const index = this.props.movieStore.selectedMovieIndex;
    const selectedMovie = movies[index];
    return (
      <div className="row" id="movie-library">
        <MoviePosters
          movies={this.props.movieStore.movies}
          selectedMovieIndex={index}
          onClick={this.props.selectMovie}
        />
        {selectedMovie &&
          <MovieDetails data={selectedMovie} />
        }
      </div>
    );
  }
}
